#
# spec file for package cdogs-sdl
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           cdogs-sdl
Version:        0.6.6
Release:        lp150.1.6
Summary:        Classic overhead run-and-gun game
License:        GPL-2.0 and BSD-2-Clause and CC-BY-3.0 and CC-BY-SA-3.0
Group:          Amusements/Games/Action/Shoot
Url:            http://cxong.github.io/cdogs-sdl
Source:         https://github.com/cxong/cdogs-sdl/archive/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  cmake >= 2.8.2
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(libenet)
BuildRequires:  pkgconfig(physfs)
BuildRequires:  pkgconfig(sdl2)

%description
C-Dogs SDL is a classic overhead run-and-gun game, supporting up to
4 players in co-op and deathmatch modes. Customize your player, choose
from up to 11 weapons, and try over 100 user-created campaigns. Have fun!

%prep
%setup -q

# use system enet
rm -rf src/cdogs/enet

dos2unix doc/original_readme.txt

# disable -Werror (aborts build on mere warnings)
sed 's| -Werror||' -i CMakeLists.txt

%build
%cmake -DCDOGS_DATA_DIR=%{_datadir}/%{name}/ -DUSE_SHARED_ENET=ON
make %{?_smp_mflags}

%install
%cmake_install

install -Dm0644 build/linux/cdogs-icon.16.png %{buildroot}%{_datadir}/icons/hicolor/16x16/apps/cdogs-sdl.png
install -Dm0644 build/linux/cdogs-icon.22.png %{buildroot}%{_datadir}/icons/hicolor/22x22/apps/cdogs-sdl.png
install -Dm0644 build/linux/cdogs-icon.32.png %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/cdogs-sdl.png
install -Dm0644 build/linux/cdogs-icon.48.png %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/cdogs-sdl.png

install -Dm0644 build/linux/cdogs-sdl.appdata.xml %{buildroot}%{_datadir}/appdata/cdogs-sdl.appdata.xml

%fdupes %{buildroot}%{_datadir}

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%{_datadir}/applications/%{name}.desktop
%{_bindir}/%{name}*
%{_datadir}/%{name}/
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml

%changelog
* Thu Nov  2 2017 mailaender@opensuse.org
- update to version 0.6.6 (New campaigns and HUD improvements)
  * New campaign, Grave Intent
  * New campaign, AI Insurgency 2
  * Update Sand campaign, new weapons
  * Update Doom campaign, new map items
  * Fix AI line-of-sight algorithm (#227)
  * Fix logging colours in Linux (#523)
  * Fix blood splatter speed (#489)
  * Fix audio panning (#507)
  * Fix recording high scores for co-op AI (#386)
  * Fix loading static wrecks in some older campaigns
  * Add new character heads - evil ogre, bones, big bones
  * Add second window (#383)
  * Add floating text for pickups (#380)
  * Add low ammo notifications (#362)
  * Add QWERTY layout name entry (#517)
  * Improve spectator HUD, show HUD (#382)
  * Improve health gauge, add animations (#360)
  * Improve co-op AI by avoiding friendly lines of fire (#295)
  * Fix copy pasting static levels (#525)
  * Fix incorrect objective counts when adding static objectives (#527)
  * Fix rescue/kill objectives not using access flags
  * Improve cave map type, add rooms, squares
- drop system-enet.patch (included upstream)
* Mon Jun  5 2017 mailaender@opensuse.org
- update to version 0.6.5
  * Add Harmful Crysalis campaign
  * Add hitscan weapons, continuous collision detection (#372)
  * Add scream sounds for females and other races (#371)
  * Add sound effect for opening/closing map (#468)
  * Add random seed to game start options
  * Fix editor crash on startup (#488)
  * Fix destroyed map objects dropping unavailable weapons (#493)
  * Fix missing custom hitsounds
  * Fix console window shown in Windows (#229)
  * Improve character editor (#462)
  * Improve Doom campaign with gun spawners, chainsaw, hitscan weapons
  * Add pickups from destroyed map objects (#367)
  * Add gas leak sound effect
  * Add pitch variations to some sound effects (#369)
  * Add some animated map objects to AI Insurgency campaign
  * Fix mission time not synced over network (#405)
  * Improve walk animation (#18)
  * Change command line option to allow arbitrary config settings (#473)
- drop upstreamed datadir.patch install-prefix.patch copying.patch
- drop cdogs-sdl-0.6.1-mga-unbundle-yajl.patch as lib is customized
- replace cdogs-sdl-0.6.0-mga-unbundle-enet.patch with system-enet.patch
* Fri Nov 18 2016 mailaender@opensuse.org
- update to version 0.6.3
  * Add new character faces (#69)
  * Add new character color keys (#441, #61)
  * Add Temple of Carnage dogfight map
  * Add bullet mass attribute (#444)
  * Add animated map objects (#430)
  * Add option to turn off brass shells (#448)
  * Add highlights for gun pickups
  * Add --nohud
  * Add Splitscreen AI config
  * Add extra logging around gun pickups
  * Fix showing map when paused (#446)
  * Fix various bugs around split screen logic
  * Fix obsolete valid graphics mode check (#449)
  * Fix gun recoil animations
- remove patches applied by upstream
  * cmake-install.patch
  * appdata.patch
- add copying.patch to fix FSF address etc.
- add datadir.patch and install-prefix.patch to fix the installer
* Sat Aug 20 2016 mailaender@opensuse.org
- initial packaging of version 0.6.2
